module.exports = defineTest({
	description: 'do not remove non an empty block statement'
});
